@@ -5,7 +5,7 @@
 # Copyright (C) 2002       Masato Taruishi <taru@debian.org>
 # Copyright (C) 2006-2008  Junichi Uekawa <dancer@debian.org>
 # Copyright (C) 2007       Famelis George <famelis@otenet.gr>
-# Copyright (C) 2008-2017  Francesco Poli <invernomuto@paranoici.org>
+# Copyright (C) 2008-2018  Francesco Poli <invernomuto@paranoici.org>
 # Copyright (C) 2009-2010  Ryan Niebur <ryan@debian.org>
 # Copyright (C) 2013       Google Inc
 #
@@ -342,7 +342,8 @@ class IgnoreBugs < Array
 
     if FileTest.exist?(path)
       begin
-        open(path).each { |bug|
+        open(path).each { |line|
+          bug = line.encode(Encoding.default_external, undef: :replace, invalid: :replace)
           if /^\s*#/ =~ bug
             next
           end
